@@ -5,9 +5,9 @@
 begin
   require 'psych'
 rescue LoadError
-  warn "#{caller[0]}:"
-  warn "It seems your ruby installation is missing psych (for YAML output)."
-  warn "To eliminate this warning, please install libyaml and reinstall your ruby."
+  warn "It seems your ruby installation is missing psych (for YAML output).\n" \
+    "To eliminate this warning, please install libyaml and reinstall your ruby.\n",
+    uplevel: 1
   raise
 end
 
